import React, { useState } from 'react';
import Modal from '@/Components/Modal';
import Input from '@/Components/FormComponents/Input';
import { useForm } from '@inertiajs/react';
import InputLabel from '@/Components/FormComponents/InputLabel';
import Button from '@/Components/Buttons/Button';
import InputTel from '@/Components/FormComponents/InputTel';
import TextArea from '@/Components/FormComponents/TextArea';
import toast from 'react-hot-toast';

export default function New({ isModalOpen, handleCloseModal }) {
    const { data, setData, post, processing, reset } = useForm({
        name: '',
        number: '',
        email: '',
        comment: ''
    });

    const onSubmit = (e) => {
        e.preventDefault();

        post(route('lead.store'), {
            onSuccess: () => {
                toast.success('Contato criado com sucesso!');
                reset();
                handleCloseModal();
            },
            onError: (errors) => {
                if (errors) {
                    toast.error(errors?.error || 'Ocorreu um erro inesperado.');
                }
            }
        });
    };

    return (
        <Modal isOpen={isModalOpen} onClose={handleCloseModal} title='Novo Contato'>
            <form onSubmit={onSubmit} className="my-4">
                <div className='mb-4'>
                    <InputLabel htmlFor="name" value="Nome" required />

                    <Input
                        id="name"
                        type="text"
                        name="name"
                        value={data.name}
                        className="block w-full"
                        autoComplete="off"
                        required
                        placeholder="Nome"
                        onChange={(e) => setData("name", e.target.value)}
                    />
                </div>

                <div className='mb-4'>
                    <InputLabel htmlFor="email" value="E-mail" />

                    <Input
                        id="email"
                        type="email"
                        name="email"
                        value={data.email}
                        className="block w-full"
                        autoComplete="off"
                        placeholder="E-mail"
                        onChange={(e) => setData("email", e.target.value)}
                    />
                </div>

                <div className='mb-4'>
                    <InputLabel htmlFor="number" value="Telefone" />

                    <InputTel
                        country={'br'}
                        value={data.number}
                        onChange={(phone) => setData("number", phone)}
                        placeholder="Telefone"
                    />
                </div>

                <div className='mb-4'>
                    <InputLabel htmlFor="comment" value="Observação" />
                    <TextArea
                        id="comment"
                        name="comment"
                        value={data.comment}
                        rows="4"
                        autoComplete="off"
                        placeholder="Observação"
                        onChange={(e) => setData("comment", e.target.value)}
                    />
                </div>

                <div className='flex justify-center mt-5'>
                    <Button className="mt-4" type="submit" disabled={processing}>Salvar contato</Button>
                </div>
            </form>
        </Modal>
    );
}